import { SimklRedirectRequest, SimklRedirectWatchedRequest } from '../../models/simkl-redirect.model.js';
import { SimklClientEndpoint } from '../../models/simkl-client.model.js';
import '../../models/simkl-common.model.js';
import '@dvcol/base-http-client';
import '@dvcol/common-utils/common/models';
import '@dvcol/common-utils/http/fetch';

/**
 * Redirect to Simkl, trailer or Twitter
 *
 * In situations when you want to link directly to the Movie or TV show episode on Simkl from your Website or APP but don't know Simkl URL, you can use the Redirect API.
 * Redirect users directly to Simkl page, Trailer or to Twitter (to Share a Simkl link on Twitter with prefilled data).
 *
 * Use CasesHere are some examples of the things you can build with the Redirect API:
 * - A browser extension to quickly link to Simkl based on page content.
 * - A website page linking directly to Simkl based on IMDB ID or TV Show name.
 * - Link to a trailer knowing only Movie name and year.
 * - Share an episode on Twitter from your browser extension.Get all Simkl IDs for your own API.
 *
 * @see [redirect]{@link https://simkl.docs.apiary.io/reference/redirect}
 */
declare const redirect: {
    /**
     * Use this if you want to make a redirect to Simkl or (fast post) to Twitter using show's title or id. It will return "location" header.
     *
     * The more parameters you'll pass, the more accurate redirect will be.
     *
     * Type show combine tv and anime types.
     *
     * The response will include the "location" header (browser redirect) where the user should be redirected.
     *
     * @see [redirect]{@link https://simkl.docs.apiary.io/reference/redirect/redirect-to-simkl-trailer-or-twitter/redirect}
     */
    to: SimklClientEndpoint<SimklRedirectRequest, unknown, false>;
    /**
     * On first use, the user will be shown the Allow dialog to allow your app mark as watched in his profile and then redirected to the episode or movie with "Marked as watched notification".
     *
     * Currently supports marking episodes in TV Shows and Anime.
     *
     * @auth client
     *
     * @see [watched]{@link https://simkl.docs.apiary.io/reference/redirect/redirect-to-simkl-trailer-or-twitter/mark-as-watched}
     */
    watched: SimklClientEndpoint<SimklRedirectWatchedRequest, unknown, false>;
};

export { redirect };
