import { SimklActivity } from '../../models/simkl-activity.model.js';
import { SimklSyncHistoryRequest, SimklSyncHistoryResponse, SimklSyncAddHistoryRequest, SimklSyncAddHistoryResponse, SimklSyncCheckRequest, SimklSyncCheckResponse, SimklSyncRemoveHistoryRequest, SimklSyncRemoveHistoryResponse, SimklSyncRatingRequest, SimklSyncAddRatingRequest, SimklSyncAddRatingResponse, SimklSyncRemoveRatingRequest, SimklSyncRemoveRatingResponse, SimklSyncAddToListRequest, SimklSyncAddToListResponse, SimklSyncAddToCollectionRequest, SimklSynAddedCollectionResponse, SimklSyncRemoveFromCollectionRequest, SimklSyncRemoveCollectionResponse } from '../../models/simkl-sync.model.js';
import { SimklClientEndpoint } from '../../models/simkl-client.model.js';
import '../../models/simkl-anime.model.js';
import '../../models/simkl-common.model.js';
import '../../models/simkl-episode.model.js';
import '../../models/simkl-rating.model.js';
import '@dvcol/base-http-client';
import '@dvcol/common-utils/common/models';
import '@dvcol/common-utils/http/fetch';
import '../../models/simkl-movie.model.js';
import '../../models/simkl-show.model.js';

/**
 * @see [sync](https://simkl.docs.apiary.io/reference/sync}
 */
declare const sync: {
    /**
     * Get last activity
     *
     * @auth user
     *
     * @see [sync-activity]{https://simkl.docs.apiary.io/reference/sync/last-activities/get-last-activity}
     */
    activity: SimklClientEndpoint<Record<string, never>, SimklActivity, true>;
    history: {
        /**
         * Get all items in the user's watchlist
         *
         * Returns all items that user has in his watchlist (watching, plan to watch, dropped, completed), shows, anime, movies.
         *
         * @auth user
         * @extended full
         *
         * @see [sync-all-items]{https://simkl.docs.apiary.io/reference/sync/get-all-items/get-all-items-in-the-user's-watchlist}
         */
        get: SimklClientEndpoint<SimklSyncHistoryRequest, SimklSyncHistoryResponse, true>;
        /**
         * Add items to watched/watching history
         *
         * Add items to the user's watched history.
         * You can pass shows, seasons, episodes and movies.
         * If no episodes for the show is passed then it will be marked as completed.
         * If seasons will be specified then only episodes in those seasons will be marked.
         *
         * If watched_at UTC datetime is passed then all will be marked as watched in the past.
         *
         * Pass as much data as possible into the item including title, year and ids fields so Simkl could detect the item better.
         *
         * @auth user
         *
         * @see [sync-add-history]{https://simkl.docs.apiary.io/reference/sync/add-items-to-the-history/add-items-to-watched/watching-history}
         */
        add: SimklClientEndpoint<SimklSyncAddHistoryRequest, SimklSyncAddHistoryResponse, false>;
        /**
         * Get specific user's watched items
         *
         * Use this method if you want to see which shows or episodes user has seen.
         * You can pass different ids and get their appropriate statuses in a user's list.
         *
         * @auth user
         *
         * @see [sync-check-history]{https://simkl.docs.apiary.io/reference/sync/check-if-watched/get-specific-user's-watched-items}
         */
        check: SimklClientEndpoint<SimklSyncCheckRequest, SimklSyncCheckResponse, false>;
        /**
         * Remove the items from the user's watched history.
         * You can pass shows, seasons, episodes and movies.
         * If no episodes are passed and the season is specified then all episodes within this season will be unmarked.
         * If seasons were skipped too then the show will be removed completely.
         * When removing show or movie, ratings are removed automatically as well for that item.
         *
         * @auth user
         *
         * @see [sync-remove-history]{https://simkl.docs.apiary.io/reference/sync/remove-items-from-history-and-from-lists/remove-items-from-watched/watching-history}
         */
        remove: SimklClientEndpoint<SimklSyncRemoveHistoryRequest, SimklSyncRemoveHistoryResponse, false>;
    };
    ratings: {
        /**
         * Get all user ratings
         *
         * @auth user
         * @extended full
         *
         * @see [sync-ratings]{https://simkl.docs.apiary.io/reference/sync/get-ratings/get-all-user's-ratings}
         */
        get: SimklClientEndpoint<SimklSyncRatingRequest, SimklSyncHistoryResponse, true>;
        /**
         * Rate the movies or tv shows/anime.
         * You cannot rate the seasons or episodes right now.
         * If the show/anime or movie is rated before it was in user's list, show will be automatically added to "Watching" list and the movie will be added to "I've seen this" list.
         * Keep in mind, when removing the show/anime or movie user's ratings will be removed as well for that item.
         *
         * @auth user
         *
         * @see [sync-add-rating]{https://simkl.docs.apiary.io/reference/sync/add-ratings/add-new-ratings}
         */
        add: SimklClientEndpoint<SimklSyncAddRatingRequest, SimklSyncAddRatingResponse, false>;
        /**
         * Remove a rating.
         *
         * Any movies or tv shows passed here will be unrated
         *
         * @auth user
         *
         * @see [sync-remove-rating]{https://simkl.docs.apiary.io/reference/sync/remove-ratings/remove-ratings}
         */
        remove: SimklClientEndpoint<SimklSyncRemoveRatingRequest, SimklSyncRemoveRatingResponse, false>;
    };
    list: {
        /**
         * Add items to specific list
         *
         * Add items to a user's Simkl lists.
         * For example you can add a Show directly to Plan to Watch or move existing show from Watching to Not Interesting.
         * You can pass shows and movies.
         * Pass as much data as possible into the item including title, year and ids fields so Simkl could detect the item better.
         *
         * @auth user
         *
         * @see [sync-add-list]{https://simkl.docs.apiary.io/reference/sync/add-item-to-the-list/add-items-to-specific-list}
         */
        add: SimklClientEndpoint<SimklSyncAddToListRequest, SimklSyncAddToListResponse, false>;
    };
    /**
     * Collection is a list of Shows\Movies that user has on his hard drive, CDs, DVDs, etc.
     * This feature is currently only supported in API and is not implemented on the website.
     */
    collection: {
        /**
         * If you want to add something to a user's collection use this method.
         * Accepts shows, season and movies.
         * If seasons skipped then all seasons for the show will be collected otherwise only specified seasons.
         * Items collected in the past should send collected_at UTC datetime.
         * If you send item second time then it will be updated with new values.
         *
         * @auth user
         *
         * @see [sync-add-collection]{https://simkl.docs.apiary.io/reference/sync/add-to-collection/add-items-to-collection}
         */
        add: SimklClientEndpoint<SimklSyncAddToCollectionRequest, SimklSynAddedCollectionResponse, false>;
        /**
         * Delete items from collection
         *
         * Using this method you can remove one or more items from a user's collection.
         *
         * @auth user
         *
         * @see [sync-remove-collection]{https://simkl.docs.apiary.io/reference/sync/remove-from-collection/delete-items-from-collection}
         */
        remove: SimklClientEndpoint<SimklSyncRemoveFromCollectionRequest, SimklSyncRemoveCollectionResponse, false>;
    };
};

export { sync };
