import {
  SimklApiError,
  SimklInvalidParameterError,
  SimklRateLimitError,
  SimklUnauthorizedError
} from "./chunk-TD2ENTDA.js";
import {
  SimklApiAuthType,
  SimklApiHeader
} from "./chunk-3HNK4KUT.js";

// lib/clients/base-simkl-client.ts
import { BaseClient } from "@dvcol/base-http-client";
import { injectCorsProxyPrefix, parseBody, parseUrl } from "@dvcol/base-http-client/utils/client";
import { BaseApiHeaders, BaseHeaderContentType } from "@dvcol/base-http-client/utils/http";
var isResponseOk = (response) => {
  if (response.type === "opaqueredirect") return response;
  if (response.status === 401) throw new SimklUnauthorizedError(response.statusText, response);
  if (response.status === 429) throw new SimklRateLimitError(response.statusText, response);
  if (!response.ok || response.status >= 400) throw new SimklApiError(response.statusText, response);
  return response;
};
var parseResponse = (response, template) => {
  isResponseOk(response);
  if (template?.opts?.pagination) response.pagination = { itemCount: null, pageCount: 1, limit: null, page: 1 };
  if (response.headers.has(SimklApiHeader.XPaginationItemCount) || response.headers.has(SimklApiHeader.XPaginationPageCount) || response.headers.has(SimklApiHeader.XPaginationLimit) || response.headers.has(SimklApiHeader.XPaginationPage)) {
    if (!response.pagination) response.pagination = { itemCount: null, pageCount: 1, limit: null, page: 1 };
    response.pagination.itemCount = Number(response.headers.get(SimklApiHeader.XPaginationItemCount));
    response.pagination.pageCount = Number(response.headers.get(SimklApiHeader.XPaginationPageCount));
    response.pagination.limit = Number(response.headers.get(SimklApiHeader.XPaginationLimit));
    response.pagination.page = Number(response.headers.get(SimklApiHeader.XPaginationPage));
  }
  return response;
};
var BaseSimklClient = class extends BaseClient {
  /**
   * Creates an instance of BaseMalClient.
   * @param options - The options for the client.
   * @param authentication - The authentication for the client.
   * @param api - The API endpoints for the client.
   */
  constructor(options, authentication = {}, api = {}) {
    super(options, authentication, api);
  }
  /**
   * Parses the template to construct the headers for a Mal API request.
   *
   * @protected
   *
   * @template T - The type of the parameters.
   *
   * @param {SimklApiTemplate<T>} template - The template for the API endpoint.
   *
   * @returns {HeadersInit} The parsed request headers.
   *
   * @throws {Error} Throws an error if OAuth is required and the access token is missing.
   */
  _parseHeaders(template) {
    const headers = {
      [BaseApiHeaders.UserAgent]: this.settings.useragent,
      [BaseApiHeaders.ContentType]: BaseHeaderContentType.Json,
      [SimklApiHeader.SimklApiKey]: this.settings.client_id
    };
    if (template.opts?.auth === SimklApiAuthType.Client && !this.settings.client_id) {
      throw new SimklInvalidParameterError("Auth required: client_id is missing");
    }
    if (template.opts?.auth === SimklApiAuthType.User && !this.auth.access_token) {
      throw new SimklInvalidParameterError("OAuth required: access_token is missing");
    }
    if (template.opts?.auth && this.auth.access_token) {
      headers[BaseApiHeaders.Authorization] = `Bearer ${this.auth.access_token}`;
    }
    return headers;
  }
  /**
   * Parses the parameters and constructs the URL for a Mal API request.
   *
   * @protected
   *
   * @template T - The type of the parameters.
   *
   * @param template - The template for the API endpoint.
   * @param {T} params - The parameters for the API call.
   *
   * @returns {string} The URL for the Mal API request.
   *
   * @throws {Error} Throws an error if mandatory parameters are missing or if a filter is not supported.
   */
  _parseUrl(template, params) {
    if (template.opts.endpoint) return parseUrl(template, params, template.opts.endpoint);
    const _template = injectCorsProxyPrefix(template, this.settings);
    return parseUrl(_template, params, this.settings.endpoint);
  }
  /**
   * Parses body from a template and stringifies a {@link BodyInit}
   *
   * @protected
   *
   * @template T - The type of the parameters.
   *
   * @param template - The expected body structure.
   * @param {T} params - The actual parameters.
   *
   * @returns {BodyInit} The parsed request body.
   */
  // eslint-disable-next-line class-methods-use-this -- implemented from abstract class
  _parseBody(template, params) {
    if (params.payload) return JSON.stringify(params.payload);
    return parseBody(template, params);
  }
  /**
   * Parses the response from the API before returning from the call.
   * @param response - The response from the API.
   *
   * @returns {SimklApiResponse} The parsed response.
   * @protected
   */
  // eslint-disable-next-line class-methods-use-this -- implemented from abstract class
  _parseResponse(response) {
    return parseResponse(response);
  }
};

export {
  isResponseOk,
  parseResponse,
  BaseSimklClient
};
