import { BaseSettings, BaseQuery, BaseRequest, ResponseOrTypedResponse, BaseOptions, BaseTemplateOptions, BaseTemplate, ClientEndpoint } from '@dvcol/base-http-client';
import { RecursiveRecord } from '@dvcol/common-utils/common/models';
import { CancellablePromise } from '@dvcol/common-utils/http/fetch';

/**
 * @see [documentation]{@link https://simkl.docs.apiary.io/#introduction/about-simkl-api/required-headers}
 */
declare const SimklApiHeader: {
    /** Simkl api key for the app */
    readonly SimklApiKey: "simkl-api-key";
    /** Current page */
    readonly XPaginationPage: "X-Pagination-Page";
    /** Items per page. */
    readonly XPaginationLimit: "X-Pagination-Limit";
    /** Total number of pages. */
    readonly XPaginationPageCount: "X-Pagination-Page-Count";
    /** Total number of items. */
    readonly XPaginationItemCount: "X-Pagination-Item-Count";
};
type SimklApiHeaders = (typeof SimklApiHeader)[keyof typeof SimklApiHeader];
/**
 * By default, methods are not returning additional data for movies, anime, show etc.
 * They return minimal info you need to match in the local database. But, if you need more information just add extended={fields} to the URL.
 *
 * Possible comma separated values for the Discover endpoints.
 *
 * @see [documentation]{@link https://simkl.docs.apiary.io/#introduction/about-simkl-api/full-info}
 */
declare const SimklApiExtended: {
    /** Complete info, except discover endpoints */
    readonly Full: "full";
    readonly Discover: "discover";
    readonly Unknown: "unknown";
};
/**
 * Represents the supported extensions for the API.
 * @see {SimklApiExtended}
 * @see [documentation]{@link https://simkl.docs.apiary.io/#introduction/about-simkl-api/full-info}
 */
type SimklApiExtends = (typeof SimklApiExtended)[keyof typeof SimklApiExtended];
/**
 * Possible comma separated values for the Discover endpoints.
 * theater value requires &user-country=us variable, otherwise US country will be taken.
 *
 * @see [documentation]{@link https://simkl.docs.apiary.io/#introduction/about-simkl-api/full-info}
 *
 */
declare const SimklApiDiscoverExtended: {
    readonly Title: "title";
    readonly Slug: "slug";
    readonly Overview: "overview";
    readonly Metadata: "metadata";
    /** Requires &user-country=us variable, otherwise US country will be taken. */
    readonly Theater: "theater";
    readonly Genres: "genres";
    readonly Tmdb: "tmdb";
    readonly All: readonly ["title", "slug", "overview", "metadata", "theater", "genres", "tmdb"];
};
/**
 * Represents the supported extensions for the API.
 * @see {SimklApiDiscoverExtended}
 * @see [documentation]{@link https://simkl.docs.apiary.io/#introduction/about-simkl-api/full-info}
 */
type SimklApiDiscoverExtends = (typeof SimklApiDiscoverExtended)[keyof Omit<typeof SimklApiDiscoverExtended, 'All'>];
type SimklApiParamsExtended<E extends SimklApiExtends = typeof SimklApiExtended.Unknown> = E extends typeof SimklApiExtended.Full ? {
    /** Extended response with full information */
    extended?: boolean | typeof SimklApiExtended.Full;
} : E extends typeof SimklApiExtended.Discover ? {
    /** Extended response with optional discover information  */
    extended?: boolean | string | SimklApiDiscoverExtends | SimklApiDiscoverExtends[];
} : {
    /** Extended response with full or optional discover information */
    extended?: boolean | typeof SimklApiExtended.Full | SimklApiDiscoverExtends | SimklApiDiscoverExtends[];
};
/**
 * Paginated endpoints will load 1 page of 10 items by default.
 *
 * @see [documentation]{@link https://simkl.docs.apiary.io/#introduction/about-simkl-api/pagination}
 */
type SimklApiClientPagination = {
    /** Number of page of results to be returned. (defaults to 1) */
    page: number;
    /** Number of results to return per page. (defaults to 10) */
    limit: number;
    /** Total number of pages */
    pageCount: number;
    /** Total number of items */
    itemCount: number;
};
type SimklApiParamsPagination = Partial<Pick<SimklApiClientPagination, 'page' | 'limit'>>;
type SimklApiParams<T extends RecursiveRecord | RecursiveRecord[] = RecursiveRecord, E extends SimklApiExtends = SimklApiExtends> = SimklApiParamsExtended<E> & SimklApiParamsPagination & T;
type SimklClientAuthentication = {
    access_token?: string;
    created?: number;
    state?: string;
};
/**
 * @see [documentation]{@link https://myanimelist.net/apiconfig/references/api/v2}
 */
type SimklClientSettings = BaseSettings<{
    /** The client ID you received from MyAnimeList when you registered your application. */
    client_id: string;
    /** The client secret you received from MyAnimeList when you registered your application. */
    client_secret: string;
    /** URI specified in your app settings. */
    redirect_uri?: string;
    /** The consumer client identifier */
    useragent: string;
}>;
type SimklApiQuery<T = unknown> = BaseQuery<BaseRequest, T>;
type SimklApiResponse<T = unknown> = ResponseOrTypedResponse<T> & {
    pagination?: SimklApiClientPagination;
};
type SimklClientOptions = BaseOptions<SimklClientSettings, SimklApiResponse>;
declare const SimklApiAuthType: {
    readonly User: "user";
    readonly Client: "client";
    readonly Both: "both";
};
type SimklApiAuthTypes = (typeof SimklApiAuthType)[keyof typeof SimklApiAuthType];
type SimklApiTemplateOptions<T extends string | number | symbol = string> = BaseTemplateOptions<T, boolean> & {
    /** Optional endpoint override */
    endpoint?: string;
    /** If the endpoint supports/requires pagination */
    pagination?: boolean;
    /** The auth type required if any */
    auth?: SimklApiAuthTypes | false;
    /** If the endpoint supports extended information */
    extends?: SimklApiExtends;
};
type SimklApiTemplate<Parameter extends SimklApiParams = SimklApiParams> = BaseTemplate<Parameter, SimklApiTemplateOptions<keyof Parameter>>;
interface SimklClientEndpoint<Parameter extends SimklApiParams = Record<string, never>, Response = unknown> {
    (param?: Parameter, init?: BodyInit): CancellablePromise<SimklApiResponse<Response>>;
}
declare class SimklClientEndpoint<Parameter extends SimklApiParams = Record<string, never>, Response = unknown, Cache extends boolean = true> extends ClientEndpoint<Parameter, Response, Cache, SimklApiTemplateOptions<keyof Parameter>> {
}
type ISimklApi<Parameter extends SimklApiParams = any, Response = unknown, Cache extends boolean = boolean> = {
    [key: string]: SimklClientEndpoint<Parameter, Response, Cache> | ISimklApi<Parameter>;
};

export { type ISimklApi, SimklApiAuthType, type SimklApiAuthTypes, type SimklApiClientPagination, SimklApiDiscoverExtended, type SimklApiDiscoverExtends, SimklApiExtended, type SimklApiExtends, SimklApiHeader, type SimklApiHeaders, type SimklApiParams, type SimklApiParamsExtended, type SimklApiParamsPagination, type SimklApiQuery, type SimklApiResponse, type SimklApiTemplate, type SimklApiTemplateOptions, type SimklClientAuthentication, SimklClientEndpoint, type SimklClientOptions, type SimklClientSettings };
